@@ -4,10 +4,11 @@
 ##  Authors:
 ##      Earl Hood         earl@earlhood.com
 ##      Detlef Pilzecker  deti@cpan.org
+##      Pavel Denisov     akreal@cpan.org
 ##  Description:
-##      Run Perl program(s) as a daemon process, see docu in the Daemon.pod file
+##      Run Perl program(s) as a daemon process, see docs in the Daemon.pod file
 ################################################################################
-##  Copyright (C) 1997-2011 by Earl Hood and Detlef Pilzecker.
+##  Copyright (C) 1997-2015 by Earl Hood, Detlef Pilzecker and Pavel Denisov.
 ##
 ##  All rights reserved.
 ##
@@ -21,7 +22,7 @@ package Proc::Daemon;
 use strict;
 use POSIX();
 
-$Proc::Daemon::VERSION = '0.14';
+$Proc::Daemon::VERSION = '0.15';
 
 
 ################################################################################
@@ -152,7 +153,8 @@ sub Init {
             die "Can't <chdir> to $self->{work_dir}: $!" unless chdir $self->{work_dir};
 
             # Clear the file creation mask.
-            umask 0;
+            $self->{_orig_umask} = umask;
+            umask 066;
 
             # Detach the child from the terminal (no controlling tty), make it the
             # session-leader and the process-group-leader of a new process group.
@@ -253,6 +255,8 @@ sub Init {
                     # potential damage later.
                 }
 
+                # Restore the original file creation mask.
+                umask $self->{_orig_umask};
 
                 # Execute a system command and never return.
                 if ( $exec_command ) {
@@ -621,7 +625,7 @@ sub get_pid_by_proc_table_attr {
 
         foreach ( @$table ) {
             # fix for Proc::ProcessTable: under some conditions $_->cmndline
-            # retruns with space and/or other characters at the end
+            # returns with space and/or other characters at the end
             next unless $_->$command =~ /^$match\s*$/;
             $pid = $_->pid;
             last;
@@ -633,4 +637,4 @@ sub get_pid_by_proc_table_attr {
     return $pid;
 }
 
-1;
\ No newline at end of file
+1;
